@@ -2,6 +2,7 @@ from enum import Enum
 
 
 class Weather(Enum):
+    INVALID = -1, "Invalid Weather"
     VOID = 0, "Void"
     SUNNY = 1, "Sunny"
     OVERCAST = 2, "Overcast"
@@ -17,6 +18,12 @@ class Weather(Enum):
     FEEDBACK = 12, "Feedback"
     REVERB = 13, "Reverb"
 
+    @classmethod
+    def _missing_(cls, value):
+        t = cls.INVALID
+        t._value_ = value
+        return t
+
     def __new__(cls, keycode, text):
         obj = object.__new__(cls)
         obj._value_ = keycode
@@ -25,6 +32,7 @@ class Weather(Enum):
 
 
 class Blood(Enum):
+    INVALID = -1, "Blood?"
     SINGLE_A = 0, "A"
     TRIPLE_A = 1, "AAA"
     DOUBLE_A = 2, "AA"
@@ -39,6 +47,12 @@ class Blood(Enum):
     PSYCHIC = 11, "Psychic"
     GRASS = 12, "Grass"
 
+    @classmethod
+    def _missing_(cls, value):
+        t = cls.INVALID
+        t._value_ = value
+        return t
+
     def __new__(cls, keycode, text):
         obj = object.__new__(cls)
         obj._value_ = keycode
@@ -47,6 +61,7 @@ class Blood(Enum):
 
 
 class Coffee(Enum):
+    INVALID = -1, "Coffee?"
     BLACK = 0, "Black"
     LIGHT_AND_SWEET = 1, "Light & Sweet"
     MACCHIATO = 2, "Macchiato"
@@ -62,6 +77,12 @@ class Coffee(Enum):
     PLENTY_OF_SUGAR = 12, "Plenty of Sugar"
     ANYTHING = 13, "Anything"
 
+    @classmethod
+    def _missing_(cls, value):
+        t = cls.INVALID
+        t._value_ = value
+        return t
+
     def __new__(cls, keycode, text):
         obj = object.__new__(cls)
         obj._value_ = keycode
@@ -70,6 +91,7 @@ class Coffee(Enum):
 
 
 class Modification(Enum):
+    INVALID = None, "????", "This Modification is unknown."
     EXTRA_STRIKE = "EXTRA_STRIKE", "The Fourth Strike", \
                    "Those with the Fourth Strike will get an extra strike in each at bat."
     SHAME_PIT = "SHAME_PIT", "Targeted Shame", \
@@ -96,13 +118,16 @@ class Modification(Enum):
                 "In the Blood Bath each season, this team will gain or lose Stars depending on how low or high they finish in their division."
     BLOOD_CHAOS = "BLOOD_CHAOS", "Blood Chaos", \
                   "In the Blood Bath each season, each player on this team will gain or lose a random amount of Stars."
-    RETURNED = "RETURNED", "Returned", "This player has Returned from the void. At the end of each season, this player has a chance of being called back to the Void."
+    RETURNED = "RETURNED", "Returned",\
+               "This player has Returned from the void. At the end of each season, this player has a chance of being called back to the Void."
     INWARD = "INWARD", "Inward", "This player has turned Inward."
     MARKED = "MARKED", "Unstable", "Unstable players have a much higher chance of being incinerated in a Solar Eclipse."
     PARTY_TIME = "PARTY_TIME", "Party Time", \
                  "This team is mathematically eliminated from the Postseason, and will occasionally receive permanent stats boost in their games."
     LIFE_OF_PARTY = "LIFE_OF_PARTY", "Life of the Party", "This team gets 10% more from their Party Time stat boosts."
-    DEBT = "DEBT", "Debted", "This player must fulfill a Debt."
+    DEBT_ZERO = "DEBT_ZERO", "Debt", "This player must fulfill a Debt."
+    DEBT = "DEBT", "Refinanced Debt", "This player must fulfill a \u24d3\u24d4\u24d1\u24e3."
+    DEBT_TWO = "DEBT_TWO", "Refinanced Debt", "This player must fulfill a \u24d3\u24d4\u24d1\u24e3."
     SPICY = "SPICY", "Spicy", "Spicy batters will be Red Hot when they get three consecutive hits."
     HEATING_UP = "HEATING_UP", "Heating Up...", \
                  "This batter needs one more consecutive hit to enter Fire mode. This mod will disappear if the batter gets out."
@@ -119,7 +144,22 @@ class Modification(Enum):
     DOUBLE_PAYOUTS = "DOUBLE_PAYOUTS", "Super Idol", \
                      "This player will earn Fans double the rewards from all Idol Pendants."
     FIRE_PROTECTOR = "FIRE_PROTECTOR", "Fire Protector", "This player will protect their team from incinerations."
-    FLICKERING = "FLICKERING", "Flickering", "This player is Flickering."
+    RECEIVER = "RECEIVER", "Receiver", "This player is a Receiver."
+    FLICKERING = "FLICKERING", "Flickering",\
+                 "Flickering players have a much higher chance of being Feedbacked to their opponent."
+    GROWTH = "GROWTH", "Growth",\
+             "Growth teams will play better as the season goes on, up to a 5% global boost by season's end."
+    BASE_INSTINCTS = "BASE_INSTINCTS", "Base Instincts",\
+                     "Batters with Base Instincts will have a chance of heading past first base when getting walked."
+    STABLE = "STABLE", "Stable", "Stable players cannot be made Unstable."
+    AFFINITY_FOR_CROWS = "AFFINITY_FOR_CROWS", "Affinity for Crows",\
+                         "Players with Affinity for Crows will hit and pitch 50% better during Birds weather."
+
+    @classmethod
+    def _missing_(cls, value):
+        t = cls.INVALID
+        t._value_ = value
+        return t
 
     def __new__(cls, keycode, text, desc):
         obj = object.__new__(cls)
@@ -148,6 +188,12 @@ class Item(Enum):
     INKY_BLAGONBALL = "INKY_BLAGONBALL", "The 2-Blood Blagonball", None
     SCORPLERS_JACKET = "SCORPLERS_JACKET", "Scorpler's Jacket", Modification.FIREPROOF
 
+    @classmethod
+    def _missing_(cls, value):
+        t = cls.INVALID_NULL
+        t._value_ = value
+        return t
+
     def __new__(cls, keycode, text, mod):
         obj = object.__new__(cls)
         obj._value_ = keycode
